@@ -2,7 +2,6 @@
 from __future__ import unicode_literals
 
 from django.contrib import admin
-from .models import ACL, ModelLookup
+from .models import ACL
 
 admin.site.register(ACL)
-admin.site.register(ModelLookup)
