@@ -4,30 +4,6 @@ from __future__ import unicode_literals
 from django.db import models
 
 from .settings import USER_MODEL, GROUP_MODEL
-from jsonfield import JSONField
-
-class ModelLookup(models.Model):
-    description = models.CharField(
-        verbose_name='short description',
-        max_length=255,
-        blank=True,
-    )
-    conditions = JSONField(
-        verbose_name='filter conditions',
-        blank=True, null=True,
-    )
-    exclusions = JSONField(
-        verbose_name='exclude conditions',
-        blank=True, null=True,
-    )
-    content_type = models.ForeignKey(
-        verbose_name='content type',
-        to='contenttypes.ContentType',
-    )
-
-    def __unicode__(self):
-        return "[%s] %s" % (self.content_type, self.description)
-
 
 class ACL(models.Model):
     """Access control list"""
@@ -42,7 +18,7 @@ class ACL(models.Model):
         null=True, blank=True
     )
     lookup = models.ForeignKey(
-        to=ModelLookup,
+        to='stored_filters.Filter',
         verbose_name='lookup',
     )
     action = models.SlugField(
